=====================
``cavcalc.parameter``
=====================

.. automodule:: cavcalc.parameter

.. currentmodule:: cavcalc.parameter

Enums
=====

.. autosummary::
    :toctree: parameter/

    Parameter

Functions
=========

.. autosummary::
    :toctree: generated/

    is_distance
	is_frequency
	is_angle
	param_to_config_type
	param_for_printing
	param_to_command_arg
